@@ -1,5 +1,3 @@
-# $Revision: 1650 $
-# $Date: 2005-07-20 00:18:17 -0300 (Wed, 20 Jul 2005) $
 
 CREATE TABLE ofUser (
   username              VARCHAR(64)     NOT NULL,
@@ -34,14 +32,6 @@ CREATE TABLE ofUserFlag (
   INDEX ofUserFlag_eTime_idx (endTime)
 );
 
-CREATE TABLE ofPrivate (
-  username              VARCHAR(64)     NOT NULL,
-  name                  VARCHAR(100)    NOT NULL,
-  namespace             VARCHAR(200)    NOT NULL,
-  privateData           TEXT            NOT NULL,
-  PRIMARY KEY (username, name, namespace(100))
-);
-
 CREATE TABLE ofOffline (
   username              VARCHAR(64)     NOT NULL,
   messageID             BIGINT          NOT NULL,
@@ -73,9 +63,9 @@ CREATE TABLE ofRoster (
 
 CREATE TABLE ofRosterGroups (
   rosterID              BIGINT          NOT NULL,
-  rank                  TINYINT         NOT NULL,
+  `rank`                  TINYINT         NOT NULL,
   groupName             VARCHAR(255)    NOT NULL,
-  PRIMARY KEY (rosterID, rank),
+  PRIMARY KEY (rosterID, `rank`),
   INDEX ofRosterGroup_rosterid_idx (rosterID)
 );
 
@@ -114,6 +104,8 @@ CREATE TABLE ofID (
 CREATE TABLE ofProperty (
   name        VARCHAR(100)              NOT NULL,
   propValue   TEXT                      NOT NULL,
+  encrypted   INTEGER,
+  iv          CHAR(24),
   PRIMARY KEY (name)
 );
 
@@ -368,8 +360,9 @@ INSERT INTO ofID (idType, id) VALUES (18, 1);
 INSERT INTO ofID (idType, id) VALUES (19, 1);
 INSERT INTO ofID (idType, id) VALUES (23, 1);
 INSERT INTO ofID (idType, id) VALUES (26, 2);
+INSERT INTO ofID (idType, id) VALUES (27, 1);
 
-INSERT INTO ofVersion (name, version) VALUES ('openfire', 25);
+INSERT INTO ofVersion (name, version) VALUES ('openfire', 30);
 
 # Entry for admin user
 INSERT INTO ofUser (username, plainPassword, name, email, creationDate, modificationDate)
